BarcodeTextPos enum

BarcodeTextPos

Enum to set how the they will be printed in barcode 0--NO_TEXT, 1--TEXT_ABOVE 2--TEXT_UNDER 3--BOTH

Inheritance
Available extensions

Values

NO_TEXT → const BarcodeTextPos
TEXT_ABOVE → const BarcodeTextPos
TEXT_UNDER → const BarcodeTextPos
BOTH → const BarcodeTextPos

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeTextPos>
A constant List of the values in this enum, in order of their declaration.