NewpasQ6PrinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NewpasQ6PrinterPlatform
Implementers

Constructors

NewpasQ6PrinterPlatform()
Constructs a NewpasQ6PrinterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindPrinter() Future<bool?>
initPrinter() Future<bool?>
lineWrap(int lines, {int height = 1}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performPrint({int feeds = 0}) Future<void>
printBarcode(String data, {BarcodeType barcodeType = BarcodeType.CODE128, int height = 162, int width = 2, BarcodeTextPos textPosition = BarcodeTextPos.TEXT_UNDER}) Future<void>
printQRCode(String data, {int size = 5, QrcodeLevel errorLevel = QrcodeLevel.LEVEL_H}) Future<void>
printRawData(Uint8List data) Future<void>
printRow({required List<ColumnMaker> cols, bool end = false}) Future<void>
printText(String text) Future<void>
setAlignment(PrintAlign alignment) Future<void>
setFontSize(FontSize size) Future<void>
toString() String
A string representation of this object.
inherited
unbindPrinter() Future<bool?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NewpasQ6PrinterPlatform
The default instance of NewpasQ6PrinterPlatform to use.
getter/setter pair