MethodChannelNewpasQ6Printer class
An implementation of NewpasQ6PrinterPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- NewpasQ6PrinterPlatform
- MethodChannelNewpasQ6Printer
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bindPrinter(
) → Future< bool?> -
override
-
initPrinter(
) → Future< bool?> -
override
-
lineWrap(
int lines, {int height = 1}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performPrint(
{int feeds = 0}) → Future< void> -
override
-
printBarcode(
String data, {BarcodeType barcodeType = BarcodeType.CODE128, int height = 162, int width = 2, BarcodeTextPos textPosition = BarcodeTextPos.TEXT_ABOVE}) → Future< void> -
override
-
printQRCode(
String data, {int size = 5, QrcodeLevel errorLevel = QrcodeLevel.LEVEL_H}) → Future< void> -
override
-
printRawData(
Uint8List data) → Future< void> -
override
-
printRow(
{required List< ColumnMaker> cols, bool end = true}) → Future<void> -
override
-
printText(
String text) → Future< void> -
override
-
setAlignment(
PrintAlign alignment) → Future< void> -
override
-
setFontSize(
FontSize size) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unbindPrinter(
) → Future< bool?> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited